@@ -79,8 +79,8 @@ public:
           widget(),
           backendData(),
           backendName(),
-          currentOwner(0),
-          deleteFunction(0)
+          currentOwner(nullptr),
+          deleteFunction(nullptr)
     {
     }
 
@@ -126,7 +126,7 @@ public:
 private:
 
     KGeoMapGlobalObject();
-    ~KGeoMapGlobalObject();
+    ~KGeoMapGlobalObject() override;
 
     class Private;
     Private* const d;
@@ -204,11 +204,11 @@ public:
 
     KGeoMapSharedData()
         : QSharedData(),
-          worldMapWidget(0),
-          tileGrouper(0),
-          markerModel(0),
+          worldMapWidget(nullptr),
+          tileGrouper(nullptr),
+          markerModel(nullptr),
           clusterList(),
-          trackManager(0),
+          trackManager(nullptr),
           showThumbnails(true),
           thumbnailSize(KGeoMapMinThumbnailSize),
           thumbnailGroupingRadius(KGeoMapMinThumbnailGroupingRadius),
@@ -220,9 +220,9 @@ public:
           modificationsAllowed(true),
           selectionRectangle(),
           haveMovingCluster(false),
-          currentMouseMode(0),
-          availableMouseModes(0),
-          visibleMouseModes(0),
+          currentMouseMode(nullptr),
+          availableMouseModes(nullptr),
+          visibleMouseModes(nullptr),
           activeState(false)
     {
     }
